@@ -1,7 +1,7 @@
 package Calendar::Dates::CFA;
 
 our $DATE = '2019-02-14'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -53,7 +53,146 @@ Calendar::Dates::CFA - CFA exam calendar
 
 =head1 VERSION
 
-This document describes version 0.002 of Calendar::Dates::CFA (from Perl distribution Calendar-Dates-CFA), released on 2019-02-14.
+This document describes version 0.003 of Calendar::Dates::CFA (from Perl distribution Calendar-Dates-CFA), released on 2019-02-14.
+
+=head1 SYNOPSIS
+
+=head2 Using from Perl
+
+ use Calendar::Dates::CFA;
+ my $min_year = Calendar::Dates::CFA->get_min_year; # => 2018
+ my $max_year = Calendar::Dates::CFA->get_max_year; # => 2019
+ my $entries  = Calendar::Dates::CFA->get_entries(2019);
+
+C<$entries> result:
+
+ [
+   {
+     date    => "2019-01-23",
+     day     => 23,
+     month   => 1,
+     summary => "Exam results announcement (Dec 2018, Levels I & II)",
+     tags    => ["dec2018exam"],
+     year    => 2019,
+   },
+   {
+     date    => "2019-02-13",
+     day     => 13,
+     month   => 2,
+     summary => "Standard registration fee deadline",
+     tags    => ["jun2019exam"],
+     year    => 2019,
+   },
+   {
+     date    => "2019-02-18",
+     day     => 18,
+     month   => 2,
+     summary => "Second deadline to request disability accommodations",
+     tags    => ["jun2019exam"],
+     year    => 2019,
+   },
+   {
+     date    => "2019-03-13",
+     day     => 13,
+     month   => 3,
+     summary => "Final (late) registration fee deadline",
+     tags    => ["jun2019exam"],
+     year    => 2019,
+   },
+   {
+     date    => "2019-03-18",
+     day     => 18,
+     month   => 3,
+     summary => "Final deadline to request disability accommodations",
+     tags    => ["jun2019exam"],
+     year    => 2019,
+   },
+   {
+     date    => "2019-06-11",
+     day     => 11,
+     month   => 6,
+     summary => "Deadline for submission of test center change requests",
+     tags    => ["jun2019exam"],
+     year    => 2019,
+   },
+   {
+     date    => "2019-06-15",
+     day     => 15,
+     month   => 6,
+     summary => "Exam day: Asia-Pacific (Levels II & III); Americas and EMEA (all levels)",
+     tags    => ["jun2019exam"],
+     year    => 2019,
+   },
+   {
+     date    => "2019-06-16",
+     day     => 16,
+     month   => 6,
+     summary => "Exam day: Asia-Pacific (Level I only)",
+     tags    => ["jun2019exam"],
+     year    => 2019,
+   },
+   {
+     date    => "2019-06-16",
+     day     => 16,
+     month   => 6,
+     summary => "Religious alternate exam date (Americas and EMEA, all levels)",
+     tags    => ["jun2019exam"],
+     year    => 2019,
+   },
+   {
+     date    => "2019-06-17",
+     day     => 17,
+     month   => 6,
+     summary => "Religious alternate exam date (Asia Pacific, all levels)",
+     tags    => ["jun2019exam"],
+     year    => 2019,
+   },
+   {
+     date    => "2019-01-24",
+     day     => 24,
+     month   => 1,
+     summary => "Exam registration open",
+     tags    => ["dec2019exam"],
+     year    => 2019,
+   },
+   {
+     date    => "2019-03-27",
+     day     => 27,
+     month   => 3,
+     summary => "Early registration fee deadline",
+     tags    => ["dec2019exam"],
+     year    => 2019,
+   },
+   {
+     date    => "2019-08-14",
+     day     => 14,
+     month   => 8,
+     summary => "Standard registration fee deadline",
+     tags    => ["dec2019exam"],
+     year    => 2019,
+   },
+   {
+     date    => "2019-09-11",
+     day     => 11,
+     month   => 9,
+     summary => "Final (late) registration fee deadline",
+     tags    => ["dec2019exam"],
+     year    => 2019,
+   },
+   {
+     date    => "2019-12-07",
+     day     => 7,
+     month   => 12,
+     summary => "Exam day",
+     tags    => ["dec2019exam"],
+     year    => 2019,
+   },
+ ]
+
+=head2 Using from CLI (requires L<list-calendar-dates> and L<calx>)
+
+ % list-calendar-dates -l -m CFA
+ % calx -c CFA
 
 =head1 DESCRIPTION
 
